@@ -1,4 +1,4 @@
-`nsize` <-
+nsize <-
 function(b, sigma = NULL, p = 0.5, conf.level = 0.95, type = "mu")
 {
     choices <- c("mu", "pi")
